units = {
    'length': {
        'm': 1,
        'km': 1e-3,
        'cm': 1e2,
        'mm': 1e3,
        'nm': 1e9,
        'um': 1e6,
        'in': 39.3701,
        'ft': 3.28084,
        'yd': 1.09361,  # yards
        'mi': 6.2137e-4,
        'nmi': 5.3996e-4  # nautical miles
    },
    'mass': {
        'kg': 1,
        'g': 1e3,
        'mg': 1e6,
        'lb': 2.20462,
        'oz': 35.274,
        'st': 0.157473,  # stone
        'ton': 0.00110231  # metric ton
    },
    'speed': {
        'mps': 1,        # meters per second (base unit)
        'kph': 3.6,      # kilometers per hour
        'mph': 2.23694,  # miles per hour
        'fps': 3.28084,  # feet per second
        'knot': 1.94384  # nautical miles per hour
    },
    'temperature': {
        'c': 1,
        'f': 1,
        'k': 1
    },
    'time': {
        's': 1,         # seconds as the base unit
        'ms': 0.001,    # milliseconds
        'min': 60,      # minutes
        'h': 3600,      # hours
        'day': 86400    # days
    }
}

def convert_units(value, from_unit, to_unit):
    from_category = None
    to_category = None
    
    for category, units_dict in units.items():
        if from_unit in units_dict:
            from_category = category
        if to_unit in units_dict:
            to_category = category
    
    if from_category != to_category:
        raise ValueError("Cannot convert between different categories")
    
    if from_category == 'temperature':
        if from_unit == 'c' and to_unit == 'f':
            return (value * 9/5) + 32
        elif from_unit == 'f' and to_unit == 'c':
            return (value - 32) * 5/9
        elif from_unit == 'c' and to_unit == 'k':
            return value + 273.15
        elif from_unit == 'k' and to_unit == 'c':
            return value - 273.15
        elif from_unit == 'f' and to_unit == 'k':
            return ((value - 32) * 5/9) + 273.15
        elif from_unit == 'k' and to_unit == 'f':
            return ((value - 273.15) * 9/5) + 32
        else:
            return value
    
    # Handle other conversions
    base_value = value * units[from_category][from_unit]
    return base_value / units[from_category][to_unit]

# Test the converter
while True:
    try:
        print("\nUnit Converter")
        print("-" * 20)
        print("Length units: m, km, cm, mm, nm, um, in, ft, yd, mi, nmi")
        print("Mass units: kg, g, mg, lb, oz, st, ton")
        print("Speed units: mps, kph, mph, fps, knot")
        print("Temperature: c, f, k")
        print("Time units: s, ms, min, h, day")
        value = float(input("Enter value: "))
        from_unit = input("From unit: ")
        to_unit = input("To unit: ")
        
        result = convert_units(value, from_unit, to_unit)
        print(value, from_unit, "=", result, to_unit)
        
        again = input("\nConvert another? (1/0): ")
        if again != '1':
            break
            
    except ValueError:
        print("Please enter a valid number for the value.")
    except Exception as e:
        print("An error occurred:", e)